@@ -40,10 +40,12 @@ fn main() -> Result<()> {
     let linker = linker
         .ok()
         .and_then(|v| v.into_iter().last())
-        .expect(&format!(
-            "Cannot locate argument '{}'",
-            build::LDPROXY_LINKER_ARG.format(Some("<linker>"))
-        ));
+        .unwrap_or_else(|| {
+            panic!(
+                "Cannot locate argument '{}'",
+                build::LDPROXY_LINKER_ARG.format(Some("<linker>"))
+            )
+        });
 
     debug!("Actual linker executable: {}", linker);
 
@@ -129,12 +131,12 @@ fn args() -> Result<Vec<String>> {
         // https://gcc.gnu.org/onlinedocs/gcc-11.2.0/gcc/Overall-Options.html)
         //
         // Deal with that
-        if arg.starts_with("@") {
-            let rsp_file = Path::new(&arg[1..]);
+        if let Some(rsp_file_str) = arg.strip_prefix('@') {
+            let rsp_file = Path::new(rsp_file_str);
             // get all arguments from the response file if it exists
             if rsp_file.exists() {
                 let contents = std::fs::read_to_string(rsp_file)?;
-                debug!("Contents of {}: {}", arg, contents);
+                debug!("Contents of {}: {}", rsp_file_str, contents);
 
                 result.extend(UnixCommandArgs::new(&contents));
             }
